@@ -5,7 +5,7 @@
 #' @param verbose Verbose diagnostic printing
 #' @param ask If multiple authors are found, should a menu be given
 #' @param secure use https vs. http
-#' @param ... arguments passed to \code{\link{GET}}
+#' @param ... arguments passed to \code{\link[httr]{GET}}
 #' 
 #' @return A character vector of the username of the author
 #' @examples
@@ -16,11 +16,11 @@
 #' @importFrom rvest html_attr html_text
 #' @importFrom utils menu
 gcite_username <- function(
-  author,
-  verbose = TRUE,
-  ask = TRUE,
-  secure = TRUE,
-  ...) {
+    author,
+    verbose = TRUE,
+    ask = TRUE,
+    secure = TRUE,
+    ...) {
   auth.names <- strsplit(author, " ")[[1]]
   auth.names <- paste(auth.names[1:length(auth.names)],
                       sep = "", collapse = "+")
@@ -89,10 +89,11 @@ gcite_username <- function(
   dat$fullnames <- paste(dat$names, dat$insts, sep = ": ")
   dat$fullnames[ is.na(dat$insts)] <- dat$names[ is.na(dat$insts)]
   
+  
   if (nrow(dat) > 1) {
     ### if they have someone for a hit
     ##grab the first hit
-    if (ask) {
+    if (ask && interactive()) {
       choice <- menu(dat$fullnames,
                      title = "More than One Author, Please Choose")
       if (choice == 0) {
@@ -100,7 +101,11 @@ gcite_username <- function(
         return(NULL)        
       }
     } else {
-      warning("Multiple authors found, first chosen")
+      msg = "Multiple authors found, first chosen"
+      if (ask) {
+        msg = paste0("Not interactive session. ", msg)
+      }
+      warning(msg)
       print(dat)
       choice = 1
     }
